@@ -1,11 +1,11 @@
 #!/bin/bash
 # PostGIS	(http://postgis.refractions.net/)
-VERSION=1.4.2
+VERSION=1.5.2
 VER=${VERSION%%.?}
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-04-12
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-10-10
 # require:
-PGVERSION=8.4.3
+PGVERSION=8.4.5
 POSTGRESQL=postgresql-$PGVERSION
 GEOS=geos-3.1.1
 PROJ=proj-4.6.1
@@ -13,7 +13,6 @@ PROJ=proj-4.6.1
 PAC_NAME=postgis-$VERSION
 SRC_FILE=${PAC_NAME}.tar.gz
 SRC_URI=http://postgis.refractions.net/download/$SRC_FILE
-#       http://postgis.refractions.net/download/postgis-1.4.0.tar.gz
 
 
 REL=P1
@@ -112,10 +111,10 @@ cd $WORK
  sed -e "s/_VER_/$VER/" \
      -e "s/_PAC_NAME_/$PAC_NAME/" \
      -e "s/_PACKAGENAME_/${PAC_NAME}-${SYS_NAME}/" \
-     $CUSTOM_DIR/doinst.sh-1.4 > install/doinst.sh
- cp -p $CUSTOM_DIR/postgis-install.sh $DOC_DIR
- cp -p $CUSTOM_DIR/postgis-upgrade.sh $DOC_DIR
- cp -p $CUSTOM_DIR/postgis-uninstall.sh $DOC_DIR
+     $CUSTOM_DIR/doinst.sh-$VER > install/doinst.sh
+ cp -p $CUSTOM_DIR/postgis-install-$VER.sh $DOC_DIR
+ cp -p $CUSTOM_DIR/postgis-upgrade-$VER.sh $DOC_DIR
+ cp -p $CUSTOM_DIR/postgis-uninstall-$VER.sh $DOC_DIR
  chown -R postgres:pgsql opt/pgsql
 
 
